aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core/SkMatrix.h
diff options
context:
space:
mode:
authorGravatar Cary Clark <caryclark@skia.org>2018-06-14 13:21:08 -0400
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2018-06-14 18:02:37 +0000
commitca6a2454b8ebc191783cff1f47198d6c0ce8c2a8 (patch)
tree4f3379a83143d2cebcb95fa10404e2e316054d91 /include/core/SkMatrix.h
parentcf274da6faa9d32e08053180c8113fcaab666028 (diff)
refresh generated includes
Found some bookmaker bugs that were suppressing spelling errors and syntax errors. TBR=reed@google.com Bug: skia:6898 Change-Id: Ie7331dd03723d987cb2df46018a984f42d0ee518 Reviewed-on: https://skia-review.googlesource.com/134942 Reviewed-by: Cary Clark <caryclark@skia.org> Commit-Queue: Cary Clark <caryclark@skia.org> Auto-Submit: Cary Clark <caryclark@skia.org>
Diffstat (limited to 'include/core/SkMatrix.h')
-rw-r--r--include/core/SkMatrix.h100
1 files changed, 50 insertions, 50 deletions
diff --git a/include/core/SkMatrix.h b/include/core/SkMatrix.h
index 84f805c637..54615a0f43 100644
--- a/include/core/SkMatrix.h
+++ b/include/core/SkMatrix.h
@@ -6,7 +6,7 @@
*/
/* Generated by tools/bookmaker from include/core/SkMatrix.h and docs/SkMatrix_Reference.bmh
- on 2018-06-08 11:48:28. Additional documentation and examples can be found at:
+ on 2018-06-14 13:13:34. Additional documentation and examples can be found at:
https://skia.org/user/api/SkMatrix_Reference
You may edit either file directly. Structural changes to public interfaces require
@@ -102,8 +102,8 @@ public:
@param skewY vertical skew factor
@param scaleY vertical scale factor
@param transY vertical translation
- @param pers0 input x perspective factor
- @param pers1 input y perspective factor
+ @param pers0 input x-axis perspective factor
+ @param pers1 input y-axis perspective factor
@param pers2 perspective scale factor
@return SkMatrix constructed from parameters
*/
@@ -179,7 +179,7 @@ public:
bool isTranslate() const { return !(this->getType() & ~(kTranslate_Mask)); }
/** Returns true SkMatrix maps SkRect to another SkRect. If true, SkMatrix is identity,
- or scales, or rotates a multiple of 90 degrees, or mirrors in x or y. In all
+ or scales, or rotates a multiple of 90 degrees, or mirrors on axes. In all
cases, SkMatrix may also have translation. SkMatrix form is either:
| scale-x 0 translate-x |
@@ -207,7 +207,7 @@ public:
}
/** Returns true SkMatrix maps SkRect to another SkRect. If true, SkMatrix is identity,
- or scales, or rotates a multiple of 90 degrees, or mirrors in x or y. In all
+ or scales, or rotates a multiple of 90 degrees, or mirrors on axes. In all
cases, SkMatrix may also have translation. SkMatrix form is either:
| scale-x 0 translate-x |
@@ -252,7 +252,7 @@ public:
Describes that the SkMatrix makes rendering with and without the matrix are
visually alike; a transformed circle remains a circle. Mathematically, this is
- referred to as similarity of a Euclidean_Space, or a similarity transformation.
+ referred to as similarity of a Euclidean space, or a similarity transformation.
Preserves right angles, keeping the arms of the angle equal lengths.
@@ -321,59 +321,59 @@ public:
return fMat[index];
}
/** Returns scale factor multiplied by x input, contributing to x output.
With mapPoints(), scales SkPoint along the x-axis.
@return horizontal scale factor
*/
SkScalar getScaleX() const { return fMat[kMScaleX]; }
/** Returns scale factor multiplied by y input, contributing to y output.
With mapPoints(), scales SkPoint along the y-axis.
@return vertical scale factor
*/
SkScalar getScaleY() const { return fMat[kMScaleY]; }
/** Returns scale factor multiplied by x input, contributing to y output.
With mapPoints(), skews SkPoint along the y-axis.
- Skew x and y together can rotate SkPoint.
+ Skewing both axes can rotate SkPoint.
@return vertical skew factor
*/
SkScalar getSkewY() const { return fMat[kMSkewY]; }
/** Returns scale factor multiplied by y input, contributing to x output.
With mapPoints(), skews SkPoint along the x-axis.
- Skew x and y together can rotate SkPoint.
+ Skewing both axes can rotate SkPoint.
@return horizontal scale factor
*/
SkScalar getSkewX() const { return fMat[kMSkewX]; }
/** Returns translation contributing to x output.
With mapPoints(), moves SkPoint along the x-axis.
@return horizontal translation factor
*/
SkScalar getTranslateX() const { return fMat[kMTransX]; }
/** Returns translation contributing to y output.
With mapPoints(), moves SkPoint along the y-axis.
@return vertical translation factor
*/
SkScalar getTranslateY() const { return fMat[kMTransY]; }
- /** Returns factor scaling input x relative to input y.
+ /** Returns factor scaling input x-axis relative to input y-axis.
- @return input x perspective factor
+ @return input x-axis perspective factor
*/
SkScalar getPerspX() const { return fMat[kMPersp0]; }
- /** Returns factor scaling input y relative to input x.
+ /** Returns factor scaling input y-axis relative to input x-axis.
- @return input y perspective factor
+ @return input y-axis perspective factor
*/
SkScalar getPerspY() const { return fMat[kMPersp1]; }
@@ -442,15 +442,15 @@ public:
*/
void setTranslateY(SkScalar v) { this->set(kMTransY, v); }
- /** Sets input x perspective factor, which causes mapXY() to vary input x inversely
- proportional to input y.
+ /** Sets input x-axis perspective factor, which causes mapXY() to vary input x-axis values
+ inversely proportional to input y-axis values.
@param v perspective factor
*/
void setPerspX(SkScalar v) { this->set(kMPersp0, v); }
- /** Sets input y perspective factor, which causes mapXY() to vary input y inversely
- proportional to input x.
+ /** Sets input y-axis perspective factor, which causes mapXY() to vary input y-axis values
+ inversely proportional to input x-axis values.
@param v perspective factor
*/
@@ -468,8 +468,8 @@ public:
@param skewY vertical skew factor to store
@param scaleY vertical scale factor to store
@param transY vertical translation to store
- @param persp0 input x perspective factor to store
- @param persp1 input y perspective factor to store
+ @param persp0 input x-axis values perspective factor to store
+ @param persp1 input y-axis values perspective factor to store
@param persp2 perspective scale factor to store
*/
void setAll(SkScalar scaleX, SkScalar skewX, SkScalar transX,
@@ -591,10 +591,10 @@ public:
Vector (sinValue, cosValue) describes the angle of rotation relative to (0, 1).
Vector length specifies scale.
- @param sinValue rotation vector x component
- @param cosValue rotation vector y component
- @param px pivot x
- @param py pivot y
+ @param sinValue rotation vector x-axis component
+ @param cosValue rotation vector y-axis component
+ @param px pivot x-axis
+ @param py pivot y-axis
*/
void setSinCos(SkScalar sinValue, SkScalar cosValue,
SkScalar px, SkScalar py);
@@ -604,8 +604,8 @@ public:
Vector (sinValue, cosValue) describes the angle of rotation relative to (0, 1).
Vector length specifies scale.
- @param sinValue rotation vector x component
- @param cosValue rotation vector y component
+ @param sinValue rotation vector x-axis component
+ @param cosValue rotation vector y-axis component
*/
void setSinCos(SkScalar sinValue, SkScalar cosValue);
@@ -671,8 +671,8 @@ public:
Matrix * T(dx, dy) = | D E F | | 0 1 dy | = | D E D*dx+E*dy+F |
| G H I | | 0 0 1 | | G H G*dx+H*dy+I |
- @param dx x translation before applying SkMatrix
- @param dy y translation before applying SkMatrix
+ @param dx x-axis translation before applying SkMatrix
+ @param dy y-axis translation before applying SkMatrix
*/
void preTranslate(SkScalar dx, SkScalar dy);
@@ -866,8 +866,8 @@ public:
T(dx, dy) * Matrix = | 0 1 dy | | M N O | = | M+dy*P N+dy*Q O+dy*R |
| 0 0 1 | | P Q R | | P Q R |
- @param dx x translation after applying SkMatrix
- @param dy y translation after applying SkMatrix
+ @param dx x-axis translation after applying SkMatrix
+ @param dy y-axis translation after applying SkMatrix
*/
void postTranslate(SkScalar dx, SkScalar dy);
@@ -1289,8 +1289,8 @@ public:
Matrix * pt = |D E F| |y| = |Ax+By+C Dx+Ey+F Gx+Hy+I| = ------- , -------
|G H I| |1| Gx+Hy+I Gx+Hy+I
- @param x x-coordinate of SkPoint to map
- @param y y-coordinate of SkPoint to map
+ @param x x-axis value of SkPoint to map
+ @param y y-axis value of SkPoint to map
@param result storage for mapped SkPoint
*/
void mapXY(SkScalar x, SkScalar y, SkPoint* result) const {
@@ -1310,8 +1310,8 @@ public:
Matrix * pt = |D E F| |y| = |Ax+By+C Dx+Ey+F Gx+Hy+I| = ------- , -------
|G H I| |1| Gx+Hy+I Gx+Hy+I
- @param x x-coordinate of SkPoint to map
- @param y y-coordinate of SkPoint to map
+ @param x x-axis value of SkPoint to map
+ @param y y-axis value of SkPoint to map
@return mapped SkPoint
*/
SkPoint mapXY(SkScalar x, SkScalar y) const {
@@ -1389,8 +1389,8 @@ public:
Matrix * vec = |D E 0| |dy| = |A*dx+B*dy D*dx+E*dy G*dx+H*dy+I| = ----------- , -----------
|G H I| | 1| G*dx+H*dy+I G*dx+*dHy+I
- @param dx x-coordinate of vector to map
- @param dy y-coordinate of vector to map
+ @param dx x-axis value of vector to map
+ @param dy y-axis value of vector to map
@param result storage for mapped vector
*/
void mapVector(SkScalar dx, SkScalar dy, SkVector* result) const {
@@ -1411,8 +1411,8 @@ public:
Matrix * vec = |D E 0| |dy| = |A*dx+B*dy D*dx+E*dy G*dx+H*dy+I| = ----------- , -----------
|G H I| | 1| G*dx+H*dy+I G*dx+*dHy+I
- @param dx x-coordinate of vector to map
- @param dy y-coordinate of vector to map
+ @param dx x-axis value of vector to map
+ @param dy y-axis value of vector to map
@return mapped vector
*/
SkVector mapVector(SkScalar dx, SkScalar dy) const {
@@ -1505,9 +1505,9 @@ public:
*/
SkScalar mapRadius(SkScalar radius) const;
- /** Returns true if a unit step in x at some y mapped through SkMatrix can be
- represented by a constant vector. Returns true if getType() returns kIdentity_Mask,
- or combinations of: kTranslate_Mask, kScale_Mask, and kAffine_Mask.
+ /** Returns true if a unit step on x-axis at some y-axis value mapped through SkMatrix
+ can be represented by a constant vector. Returns true if getType() returns
+ kIdentity_Mask, or combinations of: kTranslate_Mask, kScale_Mask, and kAffine_Mask.
May return true if getType() returns kPerspective_Mask, but only when SkMatrix
does not include rotation or skewing along the y-axis.
@@ -1516,11 +1516,11 @@ public:
*/
bool isFixedStepInX() const;
/** Returns vector representing a unit step in x at y mapped through SkMatrix.
If isFixedStepInX() is false, returned value is undefined.
@param y position of line parallel to x-axis
- @return vector advance of mapped unit step in x
+ @return vector advance of mapped unit step on x-axis
*/
SkVector fixedStepInX(SkScalar y) const;
@@ -1600,8 +1600,8 @@ public:
/** Decomposes SkMatrix into scale components and whatever remains. Returns false if
SkMatrix could not be decomposed.
- Sets scale to portion of SkMatrix that scales in x and y. Sets remaining to SkMatrix
- with x and y scaling factored out. remaining may be passed as nullptr
+ Sets scale to portion of SkMatrix that scale axes. Sets remaining to SkMatrix
+ with scaling factored out. remaining may be passed as nullptr
to determine if SkMatrix can be decomposed without computing remainder.
Returns true if scale components are found. scale and remaining are
@@ -1611,7 +1611,7 @@ public:
On success
Matrix = scale * Remaining
- @param scale x and y scaling factors; may be nullptr
+ @param scale axes scaling factors; may be nullptr
@param remaining SkMatrix without scaling; may be nullptr
@return true if scale can be computed
*/
@@ -321,59 +321,59 @@ public:
return fMat[index];
}
- /** Returns scale factor multiplied by x input, contributing to x output.
+ /** Returns scale factor multiplied by x-axis input, contributing to x-axis output.
With mapPoints(), scales SkPoint along the x-axis.
@@ -321,59 +321,59 @@ public:
*/
SkScalar getScaleX() const { return fMat[kMScaleX]; }
- /** Returns scale factor multiplied by y input, contributing to y output.
+ /** Returns scale factor multiplied by y-axis input, contributing to y-axis output.
With mapPoints(), scales SkPoint along the y-axis.
@@ -321,59 +321,59 @@ public:
*/
SkScalar getScaleY() const { return fMat[kMScaleY]; }
- /** Returns scale factor multiplied by x input, contributing to y output.
+ /** Returns scale factor multiplied by x-axis input, contributing to y-axis output.
With mapPoints(), skews SkPoint along the y-axis.
@@ -321,59 +321,59 @@ public:
*/
SkScalar getSkewY() const { return fMat[kMSkewY]; }
- /** Returns scale factor multiplied by y input, contributing to x output.
+ /** Returns scale factor multiplied by y-axis input, contributing to x-axis output.
With mapPoints(), skews SkPoint along the x-axis.
@@ -321,59 +321,59 @@ public:
*/
SkScalar getSkewX() const { return fMat[kMSkewX]; }
- /** Returns translation contributing to x output.
+ /** Returns translation contributing to x-axis output.
With mapPoints(), moves SkPoint along the x-axis.
@@ -321,59 +321,59 @@ public:
*/
SkScalar getTranslateX() const { return fMat[kMTransX]; }
- /** Returns translation contributing to y output.
+ /** Returns translation contributing to y-axis output.
With mapPoints(), moves SkPoint along the y-axis.
@@ -1516,11 +1516,11 @@ public:
*/
bool isFixedStepInX() const;
- /** Returns vector representing a unit step in x at y mapped through SkMatrix.
+ /** Returns vector representing a unit step on x-axis at y mapped through SkMatrix.
If isFixedStepInX() is false, returned value is undefined.